AdjustedArithmeticMeanRankIndex
===============================

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: AdjustedArithmeticMeanRankIndex
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~AdjustedArithmeticMeanRankIndex.binarize
      ~AdjustedArithmeticMeanRankIndex.closed_expectation
      ~AdjustedArithmeticMeanRankIndex.closed_variance
      ~AdjustedArithmeticMeanRankIndex.increasing
      ~AdjustedArithmeticMeanRankIndex.key
      ~AdjustedArithmeticMeanRankIndex.name
      ~AdjustedArithmeticMeanRankIndex.needs_candidates
      ~AdjustedArithmeticMeanRankIndex.supported_rank_types
      ~AdjustedArithmeticMeanRankIndex.supports_weights
      ~AdjustedArithmeticMeanRankIndex.synonyms
      ~AdjustedArithmeticMeanRankIndex.value_range

   .. rubric:: Methods Summary

   .. autosummary::

      ~AdjustedArithmeticMeanRankIndex.__call__
      ~AdjustedArithmeticMeanRankIndex.adjust
      ~AdjustedArithmeticMeanRankIndex.expected_value
      ~AdjustedArithmeticMeanRankIndex.extra_repr
      ~AdjustedArithmeticMeanRankIndex.get_coefficients
      ~AdjustedArithmeticMeanRankIndex.get_description
      ~AdjustedArithmeticMeanRankIndex.get_link
      ~AdjustedArithmeticMeanRankIndex.get_range
      ~AdjustedArithmeticMeanRankIndex.get_sampled_values
      ~AdjustedArithmeticMeanRankIndex.iter_extra_repr
      ~AdjustedArithmeticMeanRankIndex.numeric_expected_value
      ~AdjustedArithmeticMeanRankIndex.numeric_expected_value_with_ci
      ~AdjustedArithmeticMeanRankIndex.numeric_variance
      ~AdjustedArithmeticMeanRankIndex.numeric_variance_with_ci
      ~AdjustedArithmeticMeanRankIndex.std
      ~AdjustedArithmeticMeanRankIndex.variance

   .. rubric:: Attributes Documentation

   .. autoattribute:: binarize
   .. autoattribute:: closed_expectation
   .. autoattribute:: closed_variance
   .. autoattribute:: increasing
   .. autoattribute:: key
   .. autoattribute:: name
   .. autoattribute:: needs_candidates
   .. autoattribute:: supported_rank_types
   .. autoattribute:: supports_weights
   .. autoattribute:: synonyms
   .. autoattribute:: value_range

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: adjust
   .. automethod:: expected_value
   .. automethod:: extra_repr
   .. automethod:: get_coefficients
   .. automethod:: get_description
   .. automethod:: get_link
   .. automethod:: get_range
   .. automethod:: get_sampled_values
   .. automethod:: iter_extra_repr
   .. automethod:: numeric_expected_value
   .. automethod:: numeric_expected_value_with_ci
   .. automethod:: numeric_variance
   .. automethod:: numeric_variance_with_ci
   .. automethod:: std
   .. automethod:: variance
